@@ -15,5 +15,5 @@ class BaseChecker(BaseChecker):
         name: str,
     ) -> None:
         value: dict = self.validators[key]
-        if not re.match(value['re'], name):
+        if not re.match(value['re'], str(name)):
             self.add_message(value['msg_id'], node=node)
