@@ -23,7 +23,7 @@ FIELD_CHECKER_MSGS = {
         settings.MSG_DESCRIPTION
     ),
     f'C{settings.FIELD_MSG_ID}05': (
-        'Datetime field name must be end with _at',
+        'Datetime field name must be end with _datetime',
         'biszx-datetime-field-name',
         settings.MSG_DESCRIPTION
     ),
